package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````-!D!`#0```!HD0````0`!30`(``)
M`"@`'``;``$``'"XA```N(0!`+B$`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0#$A```Q(0```4```````$`
M`0```-B-``#8C0(`V(T"`#@"``!@$@``!@```````0`"````Y(T``.2-`@#D
MC0(`$`$``!`!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DV(T`
M`-B-`@#8C0(`*`(``"@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`9>)`!A;08TOTV_+SQ@3=6;:0C),$
M````$`````$```!'3E4```````,````"`````````&$````$````(`````H`
M``"H$A```D01(``"0`!6`'`8@@``,`@`$!$``!`"`"@`````````2`(@"@`*
M``2$`JA`"`5@80"$"#Y"/)<``0`()%B`!(E@#)-X"4)*0$0`0``!`4,)`$"`
MC,"$```0D!"#"0`(`1"`@$!`P@F`+$"8`D$`(,`@!`D`D``D#I-"0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!(````5`````````````````````````!<````:````&P``
M`!\````@````(0```"(`````````(P```"4````I`````````"L`````````
M`````"P````M````+@```"\`````````,P```#0````V````-P``````````
M````.````#L````\`````````#T````^````0````$(```!%`````````$8`
M`````````````$<`````````2```````````````````````````````````
M`$D```!*`````````$P`````````3@```%$```!3````````````````````
M`````%0```!8````60```%H`````````6P``````````````70``````````
M````7P```&$```!B````8P```&8```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-,@=+`"U634?&:OS&8N3CWVV_<`
M7@:DA_\!KS3HSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<5K&IY0
MQ8D%D&&8[Q(!(_FD0OK7AYV[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#(.4`?,V+;[3^>
M0D3I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_
M+)@BU&BZXY)\(?_D#F]Z:?J3K01BWX4@3U>DFY;%N9Q`4!M]7S&X@@V^VE<;
MLP&+;[S02WUV;^-PF4+NH6H)0]:?(L>H(6)D!WZIG)MBT/J"["SVBVM_FGR'
M\)9\%8PES.\+4?F0=8(-0V9+$#RM.0T7ZEKQIIN3'*/@^TE7DEI2_=+O#V[%
MWQ]\D!#I+=_^2"[%F[;)U;)Q``````````````````````$`````````````
M`"`````=```````````````@````+```````````````(````-("````````
M`````!(```"R`0`````````````2````0`(`````````````$@```!T"````
M`````````!(```#S`P```)`"```````@`!<`;`$`````````````$@```!8"
M`````````````!(```!<`0``?!0!```````2````>`,``!"0`@``````$``8
M`-D!`````````````!(```#[`0`````````````2````,P0```R0`@`$````
M$0`7`(,"`````````````!(```"K!```C#(!`%0"```2``T`S0,``)@D`0`D
M````$@`-`-D"`````````````!(```#A`0`````````````2````E`(`````
M````````$@```+4#```XH`(``````!``&`"8`P`````````````2````V0,`
M`#`K`0!<!P``$@`-``T$``!T(0$`T````!(`#0#``P``<"0!`"@````2``T`
M"`(`````````````$@```-0!`````````````!(```!#`0`````````````2
M````<`(`````````````$@```%<$``#80P$`1`$``!(`#0#L`@``$)`"``0`
M```A`!@`E0$`````````````$@```*$!`````````````!(```#F`P``F$(!
M`$`!```2``T`,@(`````````````$@```*T#```0D`(``````!``%P!-`@``
M```````````2````8P```(P6`0``````$@```!`"`````````````!(```"D
M`@`````````````2````S@$`````````````$@```)P!`````````````!(`
M``#M`@``$)`"``0````A`!@`0@0``#B@`@``````$``8`(T"```@D`(`!```
M`!$`&`!7`P``?$4!``0````2``T`3@$`````````````$@```"H!````````
M`````!(````C!```'$4!`&`````2``T`@@0``"0J`0`,`0``$@`-`.H!````
M`````````!(```#W`P``-!D!```````2``T`@P``````````````$@```(\`
M`````````````!(```!B`@`````````````2````LP```!B0`@`!````$0`8
M`"L"`````````````!(```#^`P``G$4!``0````1``\`800``!"0`@``````
M$``8`*L"`````````````!(```##`@`````````````2````1@``````````
M````$@```,```````````````!(```!M!```0"$!`#0````2``T`\P``````
M````````$@```#T$```XH`(``````!``&`!U!```2"(!`"@"```2``T`]0(`
M````````````$@```+H!`````````````!(```"D```````````````2````
MT0```!20`@`$````$0`8`.L"```0D`(`!````!$`&``<`0`````````````2
M````.0(`````````````$@```+0#```XH`(``````!``&`"4!```A"D!`(@`
M```2``T`=```````````````$@```'L"`````````````!(```#<````````
M```````2````\0,```"0`@``````$``7`+4"`````````````!(````'`P``
MX(T"``0````1`!0`A@,```PJ`0`8````$@`-`(H!`````````````!(```!W
M`0`````````````2````Y@(``!`7`0`D`@``$@`-`/@``````````````!(`
M``"B!```'$(!`'P````2``T`FP(`````````````$@```%L"````````````
M`!(```!'`@`````````````2````@P$`````````````$@```,L"````````
M`````!(````D`@`````````````2````2@0``+PD`0#(!```$@`-`/T`````
M`````````!(````"`@`````````````2````H0,``.`T`0!8`0``$@`-`%0`
M`````````````!(````Z`0`````````````2````9P,``$0B`0`$````$@`-
M``D!```4%@$``````!(`````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N
M`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC
M;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N
M`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S
M=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R
M<@!G971U:60`<F5A9&QI;FL`<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?
M8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`
M;&EB<&5R;"YS;RXU+C,R`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M
M;&EN=7@M87)M:&8N<V\N,P!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?
M97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T
M87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E
M;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G
M`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-``````````````"``,``@`"
M``$````"`````0`"``(``0`"``$``0`"``(``@`!``(``0`!``$``@`"````
M`@`!``(``P`#``$``@`!``(````"``(``P`#``(``0`"``$```````$``0`"
M``$```````(````"``$``0`"``(```````$````!``$``@`#```````"````
M`@`!``$````"`````0`"``0``0```````0`"``$``@`"``(``@`"``(``0``
M``(``0```````0````$``0!#`P``$````"`````4:6D-```$`,$$````````
M`0`!`"D#```0````(````!1I:0T```,`P00````````!``$`.0,``!``````
M````%&EI#0```@#!!````````/R/`@`5`@``X(T"`!13```0D`(`%$D``!20
M`@`42```&)`"`!0Y```@D`(`%"X```"/`@`6!@``!(\"`!8$```(CP(`%A<`
M``R/`@`6*P``$(\"`!85```4CP(`%CX``!B/`@`66```'(\"`!9;```@CP(`
M%@L``"2/`@`67```*(\"`!9.```LCP(`%D(``#"/`@`6.```-(\"`!9?```X
MCP(`%C0``#R/`@`610``0(\"`!8.``!$CP(`%AL``$B/`@`6,```3(\"`!9*
M``!0CP(`%EH``%2/`@`650``6(\"`!8%``!<CP(`%E8``&"/`@`63P``9(\"
M`!8A``!HCP(`%ET``&R/`@`6$P``<(\"`!8Q``!TCP(`%@(``'B/`@`6!P``
M?(\"`!8<``"`CP(`%B0``(2/`@`69```B(\"`!8I``",CP(`%C8``)"/`@`6
M(@``E(\"`!92``"8CP(`%C<``)R/`@`6'0``H(\"`!9B``"DCP(`%DL``*B/
M`@`69P``K(\"`!8_``"PCP(`%F$``+2/`@`6"0``N(\"`!8F``"\CP(`%D``
M`,"/`@`6"@``Q(\"`!9>``#(CP(`%E```,R/`@`6.@``T(\"`!8G``#4CP(`
M%CT``-B/`@`61P``W(\"`!9E``#@CP(`%A```.2/`@`6#0``Z(\"`!8H``#L
MCP(`%BH``/"/`@`6'@``](\"`!84``#XCP(`%D8```A`+>E:`0#K"("]Z`3@
M+>4$X)_E#N"/X`CPON7<>@$``,:/XA?*C.+<^KSE`,:/XA?*C.+4^KSE`,:/
MXA?*C.+,^KSE`,:/XA?*C.+$^KSE`,:/XA?*C.*\^KSE`,:/XA?*C.*T^KSE
M`,:/XA?*C.*L^KSE`,:/XA?*C.*D^KSE`,:/XA?*C.*<^KSE`,:/XA?*C.*4
M^KSE`,:/XA?*C.*,^KSE`,:/XA?*C.*$^KSE`,:/XA?*C.)\^KSE`,:/XA?*
MC.)T^KSE`,:/XA?*C.)L^KSE`,:/XA?*C.)D^KSE`,:/XA?*C.)<^KSE`,:/
MXA?*C.)4^KSE`,:/XA?*C.),^KSE`,:/XA?*C.)$^KSE`,:/XA?*C.(\^KSE
M`,:/XA?*C.(T^KSE`,:/XA?*C.(L^KSE`,:/XA?*C.(D^KSE`,:/XA?*C.(<
M^KSE`,:/XA?*C.(4^KSE`,:/XA?*C.(,^KSE`,:/XA?*C.($^KSE`,:/XA?*
MC.+\^;SE`,:/XA?*C.+T^;SE`,:/XA?*C.+L^;SE`,:/XA?*C.+D^;SE`,:/
MXA?*C.+<^;SE`,:/XA?*C.+4^;SE`,:/XA?*C.+,^;SE`,:/XA?*C.+$^;SE
M`,:/XA?*C.*\^;SE`,:/XA?*C.*T^;SE`,:/XA?*C.*L^;SE`,:/XA?*C.*D
M^;SE`,:/XA?*C.*<^;SE`,:/XA?*C.*4^;SE`,:/XA?*C.*,^;SE`,:/XA?*
MC.*$^;SE`,:/XA?*C.)\^;SE`,:/XA?*C.)T^;SE`,:/XA?*C.)L^;SE`,:/
MXA?*C.)D^;SE`,:/XA?*C.)<^;SE`,:/XA?*C.)4^;SE`,:/XA?*C.),^;SE
M`,:/XA?*C.)$^;SE`,:/XA?*C.(\^;SE`,:/XA?*C.(T^;SE`,:/XA?*C.(L
M^;SE`,:/XA?*C.(D^;SE`,:/XA?*C.(<^;SE`,:/XA?*C.(4^;SE`,:/XA?*
MC.(,^;SE`,:/XA?*C.($^;SE`,:/XA?*C.+\^+SE`,:/XA?*C.+T^+SE`,:/
MXA?*C.+L^+SE,$`MZ2303>+D,9_E%`"-Y1`0C>4,((WE%`"-XA`0C>(,((WB
M`#"3Y1PPC>4`,*#CF/__Z[PAG^6\`9_E`A"@X8H+`.NT,9_E`%#3Y0``5>.L
M09\5"0``&FK__^ND(9_E``!0XPP`@N5?```*D$&?Y4/__^L``)3EW?__ZWU7
MP.4``)3EVO__ZP`PH.$``)3EQB/3Y0(@@N/&(\/EU/__ZQ10G>4$((7B!P%R
MXP-0A>+&,]#E`3"#X\8SP.5&``"*`@&@X57__^L\(9_E$!"=Y3!!G^44P)WE
M`0!<XP`PH.$$`)+E`""1Y00PA.4`((/E&"&?Y0@`@^4$((/E$"&?Y0P@@^4U
M``#:!`!!X@P!@.`,(:#A#,"#X@3@L>4``%'A!."LY?O__QH,P(+B`!"@XP`0
MC>4%(*#A#!"#YPP`E.70$)_E=___ZP!04.(2```*#`"4Y2+__^N\`)_E&!"-
MXFL``.L``%#C#P``"@P`E.4&___K9?__ZW0PG^4`()/E'#"=Y0(@,^``,*#C
M%0``&@4`H.$DT(WB,("]Z`P`E.5^___K`%"@X>C__^H(`)3E``!0XP$```H$
M!P#KZO__ZE@`G^48$(WB40``ZP``4.,(`(3EY/__"O;__^I@___K$,"@X]#_
M_^KQ_O_K`0"@XR+__^O@C0(`%!8!`(P6`0`8D`(`%)`"`"B0`@`(D`(`6$D!
M`%Q)`0#0(`$`*$<!`,A&`0``L*#C`."@XP00G>0-(*#A!"`MY00`+>40P)_E
M!,`MY0P`G^4,,)_E__[_ZUO__^M\10$`$!<!`!Q%`0`4,)_E%""?Y0,PC^`"
M()/G``!2XQ[_+P'Z_O_J='4!``@!```8`)_E&#"?Y0``4^$>_R\!$#"?Y0``
M4^,>_R\!$_\OX1"0`@`0D`(``````"0`G^4D$)_E`#!!X*,?H.%#$8'@P1"P
MX1[_+P$0,)_E``!3XQ[_+P$3_R_A$)`"`!"0`@``````$$`MZ1A`G^4`,-3E
M``!3XQ"`O1C@___K`3"@XP`PQ.40@+WH))`"`.;__^KP1RWI`)!0XBH```JT
M,)_E`("3Y0``6.,H```*`%#9Y0%PH.$``%7C/0!5$P%0H!,`4*`#$0``&@!`
MF.4``%3C#```"@A@H.$$`*#A!2"@X0D0H.$2___K``!0XP(``!H%,-3G/0!3
MXPL```H$0+;E``!4X_/__QH$`*#A\(>]Z`E0H.$!,/7E``!3XST`4Q/[__\:
M"5!%X.;__^H(8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7PA[WH"4"@X>W__^H(
M0*#AZ___ZA"0`@!,,9_E\$$MZ0!04.)XT$WB`#"3Y70PC>4`,*#C`@``"@`P
MU>4``%/C!P``&B`QG^4`()/E=#"=Y0(@,^``,*#C0@``&GC0C>+P@;WH?O[_
MZP!`4.+T__\*^'"?Y00`H.'0_O_K``!0XRH```H3,-#E$V"`XBX`4^,"```:
M`3#6Y0``4^/T__\*$S#0Y2X`4^,E```*!0"@X8/^_^L`@*#A!@"@X8#^_^L`
M`(C@`@"`XFO^_^L',*#A`"#@XP$0H.,$8(WE`%"-Y0!@H.&%_O_K"""-X@80
MH.$#`*#CNO[_ZP$`<.,&`*#A`P``"A@PG>4/.@/B`0E3XQ(```HZ_O_K!@"@
MX1K^_^L$`*#AI?[_ZP``4./4__\:!`"@X;G^_^L%`*#A&_[_Z[___^H!,-;E
M+@!3X];__QH",-;E``!3X\7__PK2___JK/__Z^O__^H?_O_KX(T"`&A&`0`0
M0"WI<-!-XG@PG^4`$*#A`$"@X0T@H.$#`*#C`#"3Y6PPC>4`,*#CG/[_ZP``
M4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,'```*-#"?Y0`@D^5L,)WE`B`S
MX``PH.,'```:<-"-XA"`O>@"$*#C!`"@X6C^_^L0#V_AH`*@X?'__^K[_?_K
MX(T"`!!`+>D`0*#A+?[_ZP$P0.(#,(3@`P!4X0,@H#$#```Z)```Z@0`4N$"
M,*#A(0``"@(PH.$!$%+D+P!1X_C__PH#`%3A&P``*@$P0^(#`%3A&@``"@`@
MT^4O`%+C^?__&@$P0^(#``#J`!#3Y0$P0^(O`%'C`@``&@,`5.$#(*#A^/__
M.@0@0N`",(+B`0I3XP8``(H!.J#C`2""X@00H.$\`)_EROW_ZS0`G^40@+WH
M``"@XQ"`O>@#`%3AY___&@`PU.4O`%/C`@``"A!`O>@0`)_EP?W_ZA!`O>@(
M`)_EOOW_ZCB0`@!P1@$`.$8!`/!`+>D!VDWB#-!-X@$ZC>(!4*#AV!"?Y=@@
MG^4`$)'E!!"#Y0`0H.,`8*#A!!"-XL0`G^4$,(/BP?W_ZP#`4.(B``#:"#"-
MX@%`3.($X(/@!#!>Y0``4^.@,)_E`'"3Y1@``!H``%3C&@``"@0@H.$O$*#C
M!`"-X@7^_^L``%#C%```"@<`H.$K_O_K!#"@X00@C>(&$*#A#_[_ZP$ZC>),
M()_E!#"#X@`0DN4`()/E`1`RX``@H.,,```:`=J-X@S0C>+P@+WH#$"@X>;_
M_^HH,)_E`'"3Y0<`H.$6_O_K!2"@X080H.&2_?_KZO__ZH']_^O@C0(`_P\`
M`'1&`0`4D`(`\$<MZ0%`H.$`,-'EY"&?Y0C03>(]`%/C`4"!`@!0H.$$`*#A
M`""2Y00@C>4`(*#CIOW_ZPT0H.$`8*#A!0"@X<3^_^L`D%#B/0``"I_]_^L`
M`%;A-```F@!PG>68@9_E!W&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``"@4P
MH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"8Y7C]_^L``%#C!P"&
MYQ8```H`$)WE`""8Y04`H.$!,-#D`1&2YP``4^,]`%,3`##!Y08```H!(('B
M`3#0Y`(0H.$]`%/C``!3$P$PPN3Y__\:`2"@X3TPH.,`,,'E`3#4Y```4^,!
M,.+E^___&N0PG^4`()/E!#"=Y0(@,^``,*#C,P``&@C0C>+PA[WH`9!)X@$P
MU.0``%/C`3#IY?O__QKQ___JL("?Y0!PF.4`,)?E``!3XR,```H',*#A!""S
MY0D0H.$``%+C`9")XOK__QH#$('B`1&@X8`PG^4`()/E``!2XP\``!H!(*#C
M`0"@X0`@@^4[_?_K`*!0XMK__PH'$*#A"7&@X0<@H.'V_/_K`*"(Y0$PB>(`
M(*#C`R&*YP"0C>6F___J!P"@X1+]_^L``%#C`*"@X0``B.7*__\*"7&@X?+_
M_^H#D*#A"!"@X^#__^K__/_KX(T"`!"0`@`HD`(`$$`MZ0C03>)$0)_E``"4
MY8?]_^L``)3EA?W_ZS0PG^4T()_E-!"?Y3S]_^L``)3E?_W_ZR@PG^4`P*#C
M)""?Y200G^4($(WH3/W_ZPC0C>(0@+WH%)`"`,B#`0!\%`$`A$8!`%1)`0",
M,@$`H$8!`!PPG^400"WI``"3Y6S]_^L00+WH##"?Y0P@G^4,$)_E(OW_ZA20
M`@#(@P$`?!0!`(1&`0`P0"WI`MI-XAS03>*L()_E`CJ-XA0P@^(`()+E`""#
MY0`@H./Y_/_KE!"?Y90PG^64()_E\`#-X0$0H.,,`(WB!_W_ZP$:C>(!*J#C
M$!"!X@P`C>+/_/_K`$!0X@!0H+,)``"Z`0"$XMS\_^L`4%#B!0``"@$:C>($
M(*#A$!"!XIW\_^L`,*#C!##%YP(ZC>(H()_E%#"#X@`0DN4`()/E`1`RX``@
MH.,#```:!0"@X0+:C>(<T(WB,("]Z*/\_^O@C0(`Q$8!`+A&`0`!$```RO__
MZO!/+>E"W4WB!-!-XO@AG^5!/8WB`%"@X0%@H.'L`9_E$!"-XCPP@^(`()+E
M`""#Y0`@H./H_?_K+Q"@XP!`H.$%`*#AR/S_ZP``4.,.```*O`&?Y040H.$)
M___K!0"@X4$]C>*@(9_E/#"#X@`0DN4`()/E`1`RX``@H.-A```:0MV-X@30
MC>+PC[WH!0"@X:_\_^M\$9_E`("@X08`H.'D_/_K`*!0XNC__PH`,-KE9)&?
MY5QQG^4``%/C?&"-XCD```H``%3C!```"@H0H.$$`*#A0?S_ZP``4.,I```*
M"@"@X9K\_^L!$$#B`."@X0$PVN<O`%/C`3"*X`H``!H"`$#B``"*X`,00>`#
M`$#@`R"@X0"PH.,!X(/@`+##Y@'`<N4O`%SC^O__"@$PB.(.X(/@`0I>X\3_
M_ZK<()_E"3"@X0$0H.,$((WE!@"@X0$JH.,(4(WE`*"-Y8O\_^L0((WB!A"@
MX0,`H./`_/_K``!0XP,``!H@,)WE#SH#X@()4^,4```*!Q"@X0``H..H_/_K
M``!0XP"@H.&K__\*`##:Y0``4^/%__\:``!4XP(```H`,-3E+@!3XP(```I<
MH)_E`>"@X]?__^H!,-3E``!3X^O__PKX___J`1"@XP8`H.&-_/_K``!0X^7_
M_QH<`)_E!A"@X:'^_^L&`*#A&OS_ZY7__^H;_/_KX(T"`,A&`0#41@$`Y$8!
M`.A&`0!P1@$`.$8!```PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C
M^O__&A[_+^$`,%#B`P``"@`PT^4``%/C````"@G^_^H``)_E__O_ZCA&`0`P
M0"WI--!-XF3DG^5D-)_E","-X@`PD^4L,(WE`#"@XP\`ONA01)_E4%2?Y0\`
MK.@/`+[H#P"LZ``PGN6P,,SA!!"-X@0`H.%&_?_K``!0XPP```H$$)WE`""5
MY0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J
M]$.?Y>Q3G^4$$(WB!`"@X3+]_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4`
M`%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^JH0Y_EG%.?Y000
MC>($`*#A'OW_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___
M"@0P@^($()/E``!2XP0@@^3[__\:[?__ZEQ#G^5,4Y_E!!"-X@0`H.$*_?_K
M``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4`
M`%+C!""#Y/O__QKM___J$$.?Y?Q2G^4$$(WB!`"@X?;\_^L``%#C#```"@00
MG>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___
M&NW__^K$0I_EK%*?Y000C>($`*#AXOS_ZP``4.,,```*!!"=Y0`@E>4!,8+@
M!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZGA"G^5<
M4I_E!!"-X@0`H.'._/_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!
M@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J+$*?Y0Q2G^4$$(WB!`"@
MX;K\_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B
M!""3Y0``4N,$((/D^___&NW__^K@09_EO%&?Y000C>($`*#AIOS_ZP``4.,,
M```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@
M@^3[__\:[?__ZI1!G^5L49_E!!"-X@0`H.&2_/_K``!0XPP```H$$)WE`""5
MY0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___J
M2$&?Y1Q1G^4$$(WB!`"@X7[\_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4`
M`%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^H$$(WB^`"?Y6S\
M_^L`$%#B`0``"MP`G^62_?_K!!"-XN``G^5E_/_K`!!0X@$```K4`)_EB_W_
MZP00C>+,`)_E7OS_ZP`04.(,```*G`"?Y83]_^NX$)_EB`"?Y8']_^MH,)_E
M`""3Y2PPG>4"(#/@`#"@XQ,``!HTT(WB,("]Z`00C>*,`)_E3/S_ZP`04.("
M```*6`"?Y7+]_^OL___J=!"?Y0H@H.,9`(WB;/O_ZP``4./F__\:-`"?Y2,0
MC>)H_?_KXO__ZN3Z_^O4@P$`X(T"`/!&`0`0D`(`_$8!``1'`0`01P$`&$<!
M`"A'`0#(1@$`-$<!`$!'`0!,1P$`U$8!`%A'`0!L1P$`/$8!`(!'`0#L2`$`
MD$<!`*1'`0`00"WI"-!-XFQ`G^5L,)_E``"4Y0`PD^4$,(WE`#"@XP$`<.,'
M```*4#"?Y0`@D^4$,)WE`B`SX``PH.,-```:"-"-XA"`O>@T`)_E#1"@X1+\
M_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,``*`#``"$Y>O__^JP^O_K")`"
M`."-`@`T1P$`$$`MZ8WZ_^N&^O_K``!0XP``D!40@+WH<$`MZ1C03>+L,)_E
M`%"@X1`0C>+D`)_E`#"3Y10PC>4`,*#C]?O_ZP!`4.(.```*`##4Y0``4^,+
M```*!1"@X6SZ_^L``%#C$@``"J@PG^4`()/E%#"=Y0(@,^``,*#C)```&AC0
MC>)P@+WHB#"?Y0`@D^44,)WE`B`SX``PH.,%$*`!=`"?!1H``!H8T(WB<$"]
MZ`/]_^H%`*#AM?K_ZP!@H.$$`*#ALOK_ZP``AN`"`(#BG?K_ZT0PG^4`(.#C
M`1"@XQ@`C>D`4(WE-#"?Y0!`H.&V^O_K'#"?Y0`@D^44,)WE`B`SX``PH.,$
M$*`!"`"?!>3__PIH^O_KX(T"`+!'`0#D1@$`Z$8!`/!/+>D"V4WB_-!-XO`V
MG^7P%I_E`BF-X@`0D>7T$(+E`!"@X_0@@N(`<*#A!P"3Z(1`C>(,X(/B)%"#
MX@<`A.B<P(WB#P"^Z)!`C>(/`*SH`P">Z`,`C.@'`)7H!P"$Z!@0C>*@!I_E
MH?O_ZP!`4.("```*`##4Y0``4^,$`0`:)?K_ZQ[Z_^L`0%#BW0``"@!0E.4`
M`%7CV0``"@4`H.%Q^O_K@`"@X0$`@.)<^O_K`"#5Y0``4N,`8*#A"P``"DB&
MG^4&0*#A!`"@X0`@C>4(,*#A`"#@XP$0H.-Q^O_K`2#UY0)`A.(``%+C]?__
M&AP&G^6@4(WB`@``Z@0`E>0``%#C#0``"A@0C>)X^__K`$!0XOC__PH`,-3E
M``!3X_7__PK\^__K``!0X_+__PH$`*#A$_K_ZP!`4.(4```:`%"@XX20C>+X
M,(WB!3&#X'1`$^4``%3C#```"@&`A>((@8G@`##4Y0``4^,'```*!`"@X>C[
M_^L!4(7B``!0XSL``!H$0)CD``!4X_3__QH`0*#C!`"@X3/Z_^MTE9_E`*"@
MX08`H.$O^O_K``"*X`&K@.($H(KB"@"@X1CZ_^M4-9_E`"#@XP$0H.,(,(WE
M#&"-Y40UG^4`0(WE!)"-Y0"`H.$O^O_K!QV@XP@`H.$U^O_K`0!PXP,``!HF
M^O_K`!"0Y1$`4>.7```:&""-X@@0H.$#`*#C9_K_ZP!04.(8```*^!2?Y0`P
ME^7T))_E``"1Y0$0H.,`@(WE-/K_ZP!@H.,".8WBN"2?Y?0P@^(`$)+E`""3
MY0$0,N``(*#C)@$`&@8`H.$"V8WB_-"-XO"/O>@$`*#APOG_ZP!`4.*P__\*
MPO__ZB@PG>4/.@/B`0E3X^+__QHP0)WEGOG_ZP``5.'>__\:*#"=Y8,[H.&C
M.Z#A!PU3X]G__QH*`*#AU_G_ZQ@0C>(`8*#A6`2?Y0?[_^L``%#C@0``"@!`
ME^6H^?_K`!"@X00`H.$)_?_K`*!0XGH```H*`*#AVOG_ZP,`4.,`0*#A"P``
MF@0`0.(8%)_E``"*X';Y_^L``%#C!0``&@0`5./%```*!$"*X`4P5.4O`%/C
MP0``"O!#G^4`,)3E`0!SXV<```H``%/C=```"MP3G^7<`Y_E#OS_Z[OY_^O4
M<Y_EU#.?Y0`@X.,!$*#C\(#-X0QPC>7$HY_E"`"-Y08`H.'&^?_K#@``ZL'Y
M_^L`,)#E$0!3XQ```!JK^?_K`5"%X@HPH.$$(*#A`1"@XQ!PC>4,4(WE`,"@
MX08`H.$`$XWHMOG_ZP<=H.,&`*#AO/G_ZP$`<.,`0*#AZO__"@@`H.%1^?_K
M&`.?Y080H.'H^__K!@"@X;S^_^N/___J!4"@X9!@C>+X,(WB!#&#X&@`$^4`
M`%#C*@``"@%0A.(%@8;@`P``Z@0`F.0``%#C)```"@%0A>(8$(WBJ_K_ZP5`
MH.$`,%#B]O__"@`PT^4``%/C\___"DGY_^L`4%#B#/__&N?__^JP`I_E`#"7
MY=`BG^4``)#E!!"-Y0"`C>4!$*#CH?G_ZP!@H.-K___JEO[_ZP(YC>)D(I_E
M]#"#X@`0DN4`()/E`1`RX``@H..1```:!`"@X0+9C>+\T(WB\$^]Z"[Y_^H-
M`*#C4_G_ZW12G^53(*#C`&"@X?;^_^H`H)?E@O__ZD@"G^48$(WB?OK_ZP``
M4.,``(0%"```"@`PT.4``%/C,`!3$P$PH!,`,*`#`3"@$P`PA`4`,(05BO__
M&@H`H.$`$*#C./G_ZP!`4.*%__\*`E"@XP`PX.,1(.#C`%"-Y2CY_^L&(*#C
M]!"-X@0`H.'K^/_K]##=Y0``4^,"```:]3#=Y4,`4^-````*`#"@XP`@H.,`
M,(WE!`"@X0`PH.,8^?_K500`ZP!0H.$"``#J]!"-X@4`H.%O!`#K`BF@X_00
MC>($`*#AU?C_ZP`@4.+V___*!`"@X7GY_^L%$*#AM`"-XK0$`.OX,(WB,*!#
MXBRQG^6S4(WB"D"@X3%P0^(!(/7E!`"@X0LPH.$`((WE`1"@XP`@X.,G^?_K
M!0!7X0)`A.+U__\:)"&?Y0`0H.,,((WE\!#-Y2@QG^4`(.#C`1"@XP8`H.$(
MH(WE\(#-X1GY_^MG___J!$"7Y0``5.,Z__\*!`"@X03Y_^L#`%#C-O__F@0`
M0.+L$)_E``"$X*'X_^L``%#C!*"@`2___^KV,-WE00!3X[O__QKW,-WE0P!3
MX[C__QKX,-WE2`!3X[7__QKY,-WE10!3X[+__QH`,.#C!`"@X3D@X.,`4(WE
MS/C_Z_00C>($`*#A*2"@XX_X_^MH()_E]#"-X@@PC>4,((WE;#"?Y0`@X.,!
M$*#C!@"@X020C>4`@(WEZOC_ZSC__^JC^/_K^(,!`."-`@#(1@$`R$<!`#Q&
M`0!P1@$`W$<!`-!'`0`@D`(`($@!`'1(`0!\2`$`")`"`.Q(`0`T1P$`5$D!
M`)Q(`0"L2`$`Y$<!`,!'`0",2`$`A$@!`'!`+>D(T$WB$$*?Y1`RG^4``)3E
M`#"3Y00PC>4`,*#C%/G_ZP!0H.$``)3E$?G_ZV@@U>4-$*#A`#"@X>0!G^5I
M(,/ET_G_ZP``4.,"```*`##0Y3$`4^-7```*<_S_ZP``E.4#^?_KO!&?Y0,P
MH.,!(*#CF?C_ZP!04.(*```*``"4Y?OX_^L0,)7EG"&?Y0`0D^5V^/_K$#"5
MY0`PD^4(,)/E`043XU```!H``)3E\/C_ZW@1G^4#,*#C`2"@XX;X_^L`4%#B
M"@``"F0!G^4-$*#AK_G_ZP!@4.(Z```*``"4Y>/X_^L0,)7E!B"@X0`0D^5>
M^/_K/&&?Y0``E.7<^/_K`%"@X0``E.79^/_K*!&?Y0$@H..%^/_K("&?Y0`0
MH.$%`*#A4?C_ZP``E.70^/_K`""@XPT0H.$`,*#A``&?Y6D@P^62^?_K``!0
MXP!`H.$(`(;E#P``"@<=H.,$`*#A@?C_ZP$@@.(1`%#C`0!2$P`PH.$C``"*
MH#"?Y0`@D^4$,)WE`B`SX``PH.,<```:"-"-XG"`O>@$`);EO_W_ZP``4.,`
M0*#A"`"&Y>G__QJ0`)_E9OC_ZP$PT.4``%/CI?__"J/__^IH8)_E``"4Y:?X
M_^L$();E$#"5Y0`0DN4``)/E4_K_Z\+__^H``)3EG_C_ZQ`PE>4`$)/E9OC_
MZZC__^H*^/_K!""6Y3@`G^4`$)+E!""@X4WX_^L4D`(`X(T"`!A'`0#`2`$`
MQ$@!`,Q(`0#41@$`*)`"`-!(`0#H2`$`R$8!`/!(`0`420$`/#&?Y?!`+>D`
M<%#B#-!-X@`PD^4$,(WE`#"@XS,```H`,-?E``!3XS````KQ^?_K`$"@X0`P
MU.4``%/C!0``"@$@A.(O`%/C`D"@`0$PTN0``%/C^O__&NA@G^4`4%?B`5"@
M$P`PEN4!`'/C(P``"@``4^,`4*`#`5`%$@``5>,'```:N#"?Y0`@D^4$,)WE
M`B`SX``PH.,H```:#-"-XO"`O>@`,-?E``!3X_3__PJ4$)_E!""@XP0`H.%)
M^/_K``!0X^[__QIT,)_E`""3Y00PG>4"(#/@`#"@XQ<``!H'`*#A#-"-XO!`
MO>A'^?_J6`"?Y;?W_^L`0*#AS/__ZDP`G^4-$*#A#?G_ZP``4.,``(8%VO__
M"@`PT.4``%/C,`!3$P`PH`,!,*`3`#"&!=/__PH!,*#C`#"&Y<[__^JG]__K
MX(T"``B0`@#<1P$`.$8!`#1'`0#(.Y_E\$\MZ:/?3>)`$(#B@&"`X@T@H.$`
M,)/EA#*-Y0`PH.,`4*#C!,`1Y0C@$>4($('B+#2@X?\\`^(L/(/A#$2@X0P\
M@^'_2`3B/L^_Y@0P@^$&`%'A`,""Y010@N4(,(+E#%""Y1`@@N+M__\:",!-
MXG[OC>(`,*#C#$"@X0A@O.5P()3E2)"4Y700E.5,@)3E&'"4Y1Q0E.4)("+@
M!$"<Y0@0(>`'("+@!B`BX`40(>`$$"'@HD^@X8%`A.$"()+@!"""X0X`7.'P
M*,SAZ?__&O@JG^4`4)#E`!"=Y02@D.4@P)#E`A"1X`P0D>"ES:#A$$"0Y0AP
MD.488)#EBL*,X0R0D.6%PHSA`<"<X`80).`GX:#A!Q`!X`GOCN$&$"'@`<"<
MX`>/CN$($)WE".`DX`(0D>`ED:#A!>`.X`3@+N`&$)'@"I^)X06?B>$.$)'@
M$."=Y0F@*.`"X)[@#*`*X`3@GN`(H"K@"J">X!C@G>7L'8'@`N">X`C@GN!L
M@2G@`8`(X`F`*.`(@)[@(."=Y>&MBN`"X)[@81&@X0F0GN!LX2'@"N`.X&SA
M+N`.D)G@*."=Y>J-B.`"X)[@;,&.X&KA(>`(X`[@`>`NX`[`G.`PX)WEZ)V)
MX`+@GN!H@:#A`1">X&KA*.`)X`[@Z<V,X&KA+N`.$)'@[.V!X#@0G>4"$)'@
M:A&!X&FA*.`,H`K@"*`JX`H0D>!`H)WE;,&@X0*@FN`(@)K@::$LX`Z@"N#N
M'8'@::$JX`J`F.#AK8C@2("=Y0*`F.!I@8C@;I$LX`&0">`,D"G@"8"8X%"0
MG>5A$:#A`I"9X`S`F>!ND2'@"I`)X.J-B.!ND2G@"<"<X.B=C.!8P)WE`L"<
MX&[!C.!JX2'@".`.X`'@+N`.P)S@8."=Y6B!H.$"X)[@`1">X&KA*.`)X`[@
MZ<V,X&KA+N`.$)'@[.V!X&@0G>4"$)'@:A&!X&FA*.`,H`K@"*`JX`H0D>!P
MH)WE;,&@X0*@FN`(@)K@::$LX`Z@"N#N'8'@::$JX`J`F.#AO8C@>("=Y:"@
MG>4"@)C@:8&(X&Z1+.`!D`G@#)`IX`F0F."`@)WE81&@X0*`F.`,P)C@;H$A
MX`N`".#KG8G@;H$HX`C`G.#IC8S@B,"=Y0+`G.!NP8S@:^$AX`G@#N`!X"[@
M#L"<X)#@G>5ID:#A`N">X`$0GN!KX2G@".`.X.C-C.!KX2[@#A"1X.SM@>"8
M$)WE`B"1X&NQ@N!H(2G@#"`"X`D@(N`"L)O@&"B?Y6S!H.$"H)K@[AV+X`F@
MFN"HL)WE:)$LX`Z0*>`)D)K@`K";X&BQB^"PH)WE;H$LX`&`*.#AG8G@"(";
MX&$1H.$"H)K@#*":X+BPG>5NP2'@Z8V(X`G`+.`,P)K@`K";X.BMC.!NX8O@
M:<$AX,"PG>4(P"S@#.">X&B!H.$"L)O@R,"=Y0&PF^!I$2C@ZNV.X`H0(>`!
M$)O@`L"<X.Z]@>!ID8S@:A$HX-#`G>4.$"'@`9"9X&[AH.$"P)S@V!"=Y0B`
MG.!JP2[@"\`LX`R`F.`"$)'@ZYV)X.#`G>5JH8'@:Q$NX`D0(>#IC8C@`:":
MX&F1H.$"P)S@Z!"=Y0[@G.!KP2G@",`LX`S@GN`"$)'@Z*V*X/#`G>5KL8'@
M:!$IX`H0(>#J[8[@`;";X&JAH.$"P)S@^!"=Y0F0G.!HP2K@#L`LX`R0F>`"
M$)'@[KV+X&B!@>!N$2K@"Q`AX`&`F.``$9WEZYV)X`(0D>!KL:#A;L$KX`J@
MD>`($9WE"<`LX`R@FN`"$)'@Z8V(X!#!G>5NX8'@:1$KX`@0(>#HK8K@`>">
MX&B!H.$"P)S@&!&=Y0NPG.!IP2C@ZNV.X`K`+.`,L)O@`A"1X&K!*.!I$8'@
M[IV+X""QG>4.P"S@#!"1X&[AH.$"L)O@Z<V!X`B`F^!J$2[@*+&=Y0D0(>`!
M$)C@`K";X&JAB^!I@2[@,+&=Y>P=@>`,@"C@"(":X&RAH.$"L)O@X<V(X`[@
MF^!I@2K@.+&=Y0&`*.`(X)[@`B";X&F1@N!A(2K@#"`BX.R-CN`"D)G@0.&=
MY<`EG^5LP:#A`N">X`K@GN!AH8SA8;$,X`B@"N`+H(KA"N">X$BAG>7HG8G@
M`K":X&BAC.'I[8[@8;&+X`F@"N!I$:#A:)$,X`F0BN%0H9WE"Y"9X`*@FN`,
MP)K@:*&!X6BQ`>`.H`K@"Z"*X0S`FN!8H9WE[IV)X`*PFN!NH8'A:+&+X`F@
M"N#IC8S@:<&@X6Z1`>`)D(KA8*&=Y0N0F>`"H)K@`1":X&ZAC.%NL0S@"*`*
MX`N@BN$!H)K@:!&=Y>B=B>`"L)'@:!&,X>FMBN!NL8O@"1`!X&GAH.%HD0S@
M"1"!X7"1G>4+$)'@`I"9X`S`F>!HD8[A:+$.X`J0">`+D(GA#)"9X'C!G>7J
M'8'@`K"<X&BQB^!J@8[AX9V)X&'!H.$!@`C@:A$.X`$0B.$+$)'@Z;V!X(`1
MG>5J@0S@`A"1X`X0D>!JX8SA">`.X`C@CN$!X)[@B!&=Y>N-CN`"$)'@:J&!
MX&D1C.%KX:#A"Q`!X&FQ#.`+$('A"J"1X)`1G>5IL0[@`A"1X`P0D>#HS8K@
M::&.X0B@"N`+H(KA`:":X)@1G>5HL0[@`A"1X&F1@>!H$8[A#!`!X.RMBN`+
M$('A"1"1X.J]@>"@$9WE;,&@X0(0D>`.$)'@:.&,X6B1#.`*X`[@">".X0&0
MGN"H$9WEZYV)X`+@D>!J$8SA:.&.X`L0`>!K@:#A:K$,X`L0@>$.X)'@L!&=
MY6JQ".`"$)'@#!"1X.G-CN!JX8CA">`.X`O@CN$!$)[@N.&=Y6FQ".`"X)[@
M:N&.X.RM@>!I$8CA#!`!X`L0@>$.X)'@P!&=Y6S!H.$"$)'@"!"1X&F!C.%I
ML0S@"H`(X`N`B.$$,(#E`8"8X,@1G>7J[8[@`A"1X&F1@>!J$8SA:K$,X`X0
M`>`+$('A"9"1X-`1G>7NC8C@`A"1X&[AH.$,$)'@:L&.X6JQ#N`(P`S@"\",
MX0'`G.#8$9WEZ)V)X`(@D>!H$8[A:+$.X`D0`>!JH8+@"Q"!X=`BG^4*$)'@
MX*&=Y>G-C.`"H)K@:9&@X>BQG>4.X)K@[*V!X&@1*>`,$"'@`>">X`*PF^!L
M$2G@:(&+X/"QG>4*$"'@ZNV.X`&`F.!JH:#A`K";X`FPF^#X$9WE;)$JX`Z0
M*>`)D)O@`A"1X.Z-B.``LIWE;,&!X&X1*N`($"'@Z)V)X`'`G.!H@:#A`K";
MX`JPF^`($IWE;J$HX`F@*N`*H)O@`A"1X.G-C.`0LIWE;N&!X&D1*.`,$"'@
M[*V*X`'@GN!LP:#A`K";X`BPF^`8$IWE:8$LX`J`*.`(@)O@`A"1X.KMCN`@
MLIWE:9&!X&H1+.`.$"'@[HV(X`&0F>!NX:#A`K";X`RPF^`H$IWE:L$NX`C`
M+.`,P)O@`A"1X.B=B>`PLIWE:J&!X&@1+N`)$"'@Z<V,X`&@FN!ID:#A`K";
MX`ZPF^`X$IWE:.$IX`S@+N`.X)O@`A"1X.RMBN!`LIWE:(&!X&P1*>`*$"'@
MZNV.X`&`F.!JH:#A`K";X`FPF^!($IWE;)$JX`Z0*>`)D)O@`A"1X.Z-B.!0
MLIWE;,&!X&X1*N`($"'@Z)V)X`'`G.!H@:#A`K";X`JPF^!8$IWE;J$HX`F@
M*N`*H)O@`A"1X.G-C.!@LIWE;N&!X&D1*.`,$"'@[*V*X`'@GN!LP:#A`K";
MX`BPF^!I@2S@ZNV.X`J`*.`(@)O@[HV(X&@2G>5H88;@`A"1X&F1@>`88(#E
M<!*=Y6IA+.`.8";@!I"9X`(0D>`,$)'@Z,V)X&[AH.%L083@:F$NX!!`@.5X
M0IWE"&`FX`80D>`"()3@!2"2X&JA@N!H(2[@[!V!X`P@(N`@P)#E`J":X.$M
MBN`'$)'@#.">X`PP@.44,(#E'#"`Y0`@@.4($(#E(."`Y20P@.4<,)_E`""3
MY80RG>4"(#/@`#"@XP$``!JCWXWB\(^]Z*[T_^O@C0(`F7F"6J'KV6[<O!N/
MUL%BRA!`+>F``*#CRO3_ZPY[G^T`(*#C`'N`[0U[G^UX((#E`GN`[0Q[G^T$
M>X#M#'N?[09[@.T,>Y_M"'N`[0Q[G^T*>X#M#'N`[1"`O>@!(T5G`````(FK
MS>\`````_MRZF`````!V5#(0`````/#ATL,```````````````#P1RWI`I"@
MX2@PD.4L()#EB>&#X`,`7N$`P*#C`C#<X`!0H.$P()#E`4"@X300D.7)#Z#A
M`@``*@$PDN(#(*#A`!"AXJD^H.&`,8/A`C"3X*`>H>!X`)7E.("%X@``4.,H
MX(7E+,"%Y3`PA>4T$(7E'P``&C\`6>,N``#:0)!)XBECH.$!<(;B!W.$X`@P
MH.%`X(3B`,"4Y00`E.4($)3E#""4Y1!`A.(.`%3A`,"#Y00`@^4($(/E#""#
MY1`P@^+S__\:!0"@X;3\_^L'`%3A[?__&@9M9N`&DXG@"2"@X0<0H.$(`*#A
M.O3_ZWB0A>7PA[WH0'!@X@<`6>$)<*"Q``"(X`<@H.$$$*#A,?3_ZW@PE>4#
M,(?@0`!3XW@PA>7PA[T8!0"@X0>02>`'0(3@FOS_Z\[__^H$<*#AYO__ZO!!
M+>DX<('B*""1Y3!@D>4RC[_FHC&@X3\P`^(!((/B`4"@X3@`4N-_$.#C`%"@
MX39OO^8"`(?@`Q#'YSP``-I`(&+B`!"@XWCT_^L$`*#A@OS_ZP<`H.$X(*#C
M`!"@XW+T_^L$`*#A<&"$Y72`A.5Z_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`
M,)3E(S2@X0(PQ>4`,)3E`S#%Y0LPU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08P
MQ>4(,)3E!S#%Y1,PU.4(,,7ELC'4X0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%
MY1LPU.4,,,7ENC'4X0TPQ>48,)3E(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7E
MLC+4X1$PQ>4@,)3E(S2@X1(PQ>4@,)3E$S#%Y?!!O>C5\__J."!BX@`0H.,[
M]/_KQ___ZO!'+>D`<*#A2&"?Y4A0G^4&8(_@!5"/X`5@1N`!@*#A`I"@X:WS
M_^M&8;#A\(>]"`!`H.,$,)7D"2"@X0@0H.$'`*#A`4"$XC/_+^$$`%;A]___
M&O"'O>BH2`$`H$@!`![_+^$(,)_E`S"/X``PD^7/\__J>$H!``A`+>D(@+WH
M`0`"`#H````]````"@```#T````/````/0```"0````]````,@```#T````"
M````/0````4````]````$P```#T````-````/0````P````]````(P```#T`
M```1````/0```"8````]`````0```#T````7````/0````@````]````"0``
M`#T``````````````"]T;7``````+@```%!!4E]435!$25(``%1%35!$25(`
M5$U0`%5315(`````55-%4DY!344`````)7,O)7,````O````+W!R;V,O<V5L
M9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%27U1%35``````4$%2
M7U!23T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,24(`
M4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,
M3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``$Q$7TQ)0E)!
M4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E
M<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4Q````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`````M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B
M)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M
M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M
M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN
M4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@
M("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("13
M24=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]
M("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY
M("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G
M:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?
M<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@
M>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H
M)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*
M<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'
M24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@
M/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@
M+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL
M(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR
M96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF
M("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF
M;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB
M+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@
M;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F
M:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D
M9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D
M9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N
M86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")0
M2UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@
M("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM0
M05)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P
M87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D
M9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D
M<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O
M(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A
M<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@
M:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P
M-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]7
M4D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE
M("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_
M(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N
M9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L
M>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@
M=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]
M("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q
M*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E
M*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S
M*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F
M:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E
M;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D
M9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L
M90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D
M0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N
M86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L
M<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$[
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@
M(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM
M93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B
M.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM
M>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M
M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@
M>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L
M("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE
M.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S
M92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D
M93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E
M;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N
M86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]
M"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@
M;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@
M+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[
M7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA
M<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]
M"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I
M(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@
M/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O
M9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D
M)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE4
M24%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%2
M7TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,
M14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=0
M05)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M(&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?
M8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY
M("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%
M04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!
M4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I
M970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E
M('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#
M;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD[
M"GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q
M<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G
M;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P```%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````#!&`0`X1@$`````
M`#Q&`0!`1@$`2$8!`,Q&`0!01@$``````%1&`0!<1@$``````#H````]````
M"@```#T````/````/0```"0````]````,@```#T````"````/0````4````]
M````$P```#T````-````/0````P````]````(P```#T````1````/0```"8`
M```]`````0```#T````7````/0````@````]````"0```#T`````````````
M`'R4_W\!````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(!H!
M`/@9`0```````0```!D#```!````*0,```$````Y`P```0```$,#```,````
M_!,!``T```"410$`&0```-B-`@`;````!````!H```#<C0(`'`````0```#U
M_O]OM`$!``4```#8"P$`!@```%@%`0`*````RP0```L````0````%0``````
M```#````](X"``(```#X`0``%````!$````7````!!(!`!$```#4$0$`$@``
M`#`````3````"````!X````(````^___;P$```#^__]O=!$!`/___V\#````
M\/__;Z00`0``````````````````````````````````````````````````
M``````````````#DC0(````````````(%`$`"!0!``@4`0`(%`$`"!0!``@4
M`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!
M``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`
M"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(
M%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4
M`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!``@4`0`(%`$`"!0!
M``@4`0````````````````#_____8$D!`$=#0SH@*%)A<W!B:6%N(#$P+C(N
M,"TQ-BMR<&DQ*2`Q,"XR+C``02X```!A96%B:0`!)`````4V``8&"`$)`0H"
M$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN
M<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M``````L````!`````@```%0!`0!4`0``&0```````````````0`````````3
M````!P````(```!P`0$`<`$``"0```````````````0`````````)@````<`
M```"````E`$!`)0!```@```````````````$`````````#0```#V__]O`@``
M`+0!`0"T`0``I`,```4`````````!`````0````^````"P````(```!8!0$`
M6`4``(`&```&`````0````0````0````1@````,````"````V`L!`-@+``#+
M!``````````````!`````````$X```#___]O`@```*00`0"D$```T`````4`
M`````````@````(```!;````_O__;P(```!T$0$`=!$``&`````&`````P``
M``0`````````:@````D````"````U!$!`-01```P````!0`````````$````
M"````',````)````0@````02`0`$$@``^`$```4````6````!`````@```!\
M`````0````8```#\$P$`_!,```P```````````````0`````````=P````$`
M```&````"!0!``@4```(`P`````````````$````!````((````!````!@``
M`!`7`0`0%P``A"X`````````````"`````````"(`````0````8```"410$`
ME$4```@```````````````0`````````C@````$````"````G$4!`)Q%```<
M/P`````````````$`````````)8````!``!P@@```+B$`0"XA```"`````T`
M````````!`````````"A`````0````(```#`A`$`P(0```0`````````````
M``0`````````JP````X````#````V(T"`-B-```$```````````````$````
M!````+<````/`````P```-R-`@#<C0``!```````````````!`````0```##
M`````0````,```#@C0(`X(T```0```````````````0`````````T`````8`
M```#````Y(T"`.2-```0`0``!@`````````$````"````-D````!`````P``
M`/2.`@#TC@``#`$`````````````!`````0```#>`````0````,`````D`(`
M`)```!````````````````0`````````Y`````@````#````$)`"`!"0```H
M$``````````````(`````````.D````!````,``````````0D```)@``````
M`````````0````$```#R`````P``<```````````-I```"\`````````````
M``$``````````0````,``````````````&60```"`0`````````````!````
$````````
